@@ -78,8 +78,11 @@ def version():
         - test my_scp.exe       # 2.7.2
         - test my_scp.exe       # 2.7.3
         - test my_scp.exe       # 2.7.4
+        - `BaseListView`再次简化, 默认`filter_fields`改为`__all__`,        # 2.7.5
+        - 默认`auto_generate_serializer_class`改为True
+        - 增加`default_page_size`字段, 且`default_page_size`为`__all__`时, 返回全部数据
     """
-    v = "2.7.4"
+    v = "2.7.5"
     return v
 
 
