@@ -139,6 +139,9 @@ def get_base_serializer(base_model, base_fields='__all__', auto_generate_annotat
     :param auto_generate_annotate_fields: 指定将自动生成的annotate的字段, 为[True, '__all__']时自动替换为base_fields
     :return:
     """
+    if base_fields == ['__all__']:
+        base_fields = '__all__'
+
     base_model = get_base_model(base_model)
     field_names = get_field_names_by_model(base_model)
     if base_fields != '__all__' and auto_generate_annotate_fields is None:
