@@ -20,14 +20,14 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     pagination_class = Pagination
 
-    filter_fields = []  # ['__all__']过滤所有. 精确检索的过滤字段, 如果过滤条件复杂的话, 建议重写
+    filter_fields = '__all__'  # '__all__'过滤所有. 精确检索的过滤字段, 如果过滤条件复杂的话, 建议重写
 
     order_type_ls = []
     distinct_field_ls = []
     only_get_distinct_field = False  # 仅返回distinct指定的字段
 
     serializer_class = None
-    auto_generate_serializer_class = False
+    auto_generate_serializer_class = True
     base_fields = '__all__'  # 当auto_generate_serializer_class为True时, 将自动生成序列化器, 然后根据base_fields返回字段
 
     list_fields = None
@@ -44,9 +44,10 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     post_type_ls = ["list", "retrieve", "bulk_list"]  # post请求方法
     create_unique = True  # 创建时是否允许重复
 
-    convert_to_bool_flag = 'bool__'                       # 将特定格式强制转换为布尔变量, 如 `名字不为空: name__isnull=bool_0`
+    convert_to_bool_flag = 'bool__'                       # 将特定格式强制转换为布尔变量, 如 `名字不为空: name__isnull=bool__0`
     negative_flag = '!'                                   # filter_fields 条件取否时使用, 如: `id不等于1: !id=1`
 
+    default_page_size = None        # 默认每页返回的数量
     # add_host_prefix_to_media_url = True                                    # 是否返回文件的时候加上当前域名的prefix
 
     def __new__(cls, *args, **kwargs):
@@ -68,6 +69,12 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
                     base_fields=cls.retrieve_fields,
                 )
 
+        if cls.default_page_size is not None and cls.pagination_class is not None:
+            if cls.default_page_size == '__all__':
+                cls.pagination_class.page_size = -999       # 返回全部
+            else:
+                cls.pagination_class.page_size = cls.default_page_size
+
         return ret
 
     def get(self, request, *args, **kwargs):
